summaryrefslogtreecommitdiff
path: root/tests/patterntest.c
diff options
context:
space:
mode:
Diffstat (limited to 'tests/patterntest.c')
-rw-r--r--tests/patterntest.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/tests/patterntest.c b/tests/patterntest.c
index 81c49b905..2bb77bd45 100644
--- a/tests/patterntest.c
+++ b/tests/patterntest.c
@@ -68,9 +68,10 @@ match_type_name (GMatchType match_type)
}
}
-/* this leakes memory, but we don't care */
-
-#define utf8(str) g_convert (str, -1, "Latin1", "UTF-8", NULL, NULL, NULL)
+/* This leakes memory, but we don't care. The utf8 macro used to convert utf8
+ back to Latin1 for feeding it to g_print. As of 2.0.1, g_print expects utf8,
+ so this is no longer necessary */
+#define utf8(str) str
#define latin1(str) g_convert (str, -1, "UTF-8", "Latin1", NULL, NULL, NULL)
static gboolean